@@ -1,4 +1,5 @@
 import random
+from datetime import datetime
 from collections import namedtuple
 from PIL import Image, ImageFilter
 from PIL.Image import Image as IMG
@@ -1228,3 +1229,44 @@ def painter(img: BuildImage = UserImg(), arg=NoArg()):
     frame = load_image("painter/0.png")
     frame.paste(img, (125, 91), below=True)
     return frame.save_jpg()
+
+
+def repeat(
+    users: List[UserInfo] = Users(1, 5), sender: UserInfo = Sender(), arg: str = Arg()
+):
+    def single_msg(user: UserInfo) -> BuildImage:
+        user_img = user.img.convert("RGBA").circle().resize((100, 100))
+        user_name_img = Text2Image.from_text(f"{user.name}", 40).to_image()
+        time = datetime.now().strftime("%H:%M")
+        time_img = Text2Image.from_text(time, 40, fill="gray").to_image()
+        bg = BuildImage.new("RGB", (1079, 200), (248, 249, 251, 255))
+        bg.paste(user_img, (50, 50), alpha=True)
+        bg.paste(user_name_img, (175, 45), alpha=True)
+        bg.paste(time_img, (200 + user_name_img.width, 50), alpha=True)
+        bg.paste(text_img, (175, 100), alpha=True)
+        return bg
+
+    text = arg or "救命啊"
+    text_img = Text2Image.from_text(text, 50).to_image()
+    if text_img.width > 900:
+        return TEXT_TOO_LONG
+
+    msg_img = BuildImage.new("RGB", (1079, 1000))
+    for i in range(5):
+        index = i % len(users)
+        msg_img.paste(single_msg(users[index]), (0, 200 * i))
+    msg_img_twice = BuildImage.new("RGB", (msg_img.width, msg_img.height * 2))
+    msg_img_twice.paste(msg_img).paste(msg_img, (0, msg_img.height))
+
+    input_img = load_image("repeat/0.jpg")
+    self_img = sender.img.convert("RGBA").circle().resize((75, 75))
+    input_img.paste(self_img, (15, 40), alpha=True)
+
+    frames: List[IMG] = []
+    for i in range(50):
+        frame = BuildImage.new("RGB", (1079, 1192), "white")
+        frame.paste(msg_img_twice, (0, -20 * i))
+        frame.paste(input_img, (0, 1000))
+        frames.append(frame.image)
+
+    return save_gif(frames, 0.08)
